@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2009-2018, Luis Pedro Coelho <luis@luispedro.org>
+# Copyright (C) 2009-2020, Luis Pedro Coelho <luis@luispedro.org>
 # vim: set ts=4 sts=4 sw=4 expandtab smartindent:
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -142,10 +142,11 @@ def hash_with_mtime_size(path):
 def timed_path(path):
     '''path = timed_path(path)
 
-    Returns a Task object that simply returns `path` with the exception that it
-    uses the paths mtime (modification time) and the file size in the hash.
-    Thus, if the file is touched or changes size, this triggers an invalidation
-    of the results (which propagates to all dependent tasks).
+    Returns an  object that returns `path` when passed to a jug Task with the
+    exception that it uses the paths mtime (modification time) and the file
+    size in the hash. Thus, if the file is touched or changes size, this
+    triggers an invalidation of the results (which propagates to all dependent
+    tasks).
 
     Parameters
     ----------
@@ -254,8 +255,9 @@ def cached_glob(pat):
     '''
     A short-hand for
 
-        from glob import globg
-        CacheFunction(glob, pattern)
+        from jug import CachedFunction
+        from glob import glob
+        CachedFunction(glob, pattern)
 
     with the extra bonus that results are returns *sorted*
 
